@@ -3,7 +3,7 @@ package PLS;
 use strict;
 use warnings;
 
-our $VERSION = '0.905';
+our $VERSION = '0.906';
 
 =head1 NAME
 
@@ -59,33 +59,47 @@ C<pls.args> would be C<< ["run", "--rm", "-i", "<image name>", "pls"] >>.
 
 =item pls.inc - a list of paths to add to C<@INC>
 
-You can use the C<$ROOT_PATH> mnemonic to stand in for your project's root directory,
-for example C<$ROOT_PATH/lib>. If you are using multiple workspace folders and use
-C<$ROOT_PATH>, the path will be multiplied by the number of workspace folders,
+You can use the C<${workspaceFolder}> variable to stand in for your project's root directory,
+for example C<${workspaceFolder}/lib>. If you are using multiple workspace folders and use
+C<${workspaceFolder}>, the path will be multiplied by the number of workspace folders,
 and will be replaced that many times. This is useful if you use SVN and check out
 each branch to a different directory.
 
 =item pls.cwd - the working directory to use for pls
 
-If you use C<$ROOT_PATH>, it will be replaced by your workspace's first
+If you use C<${workspaceFolder}>, it will be replaced by your workspace's first
 or only folder.
 
 =item pls.perltidy.perltidyrc - the location of your C<.perltidyrc> file.
 
 Defaults to C<~/.perltidyrc> if not configured.
 
+If you use C<${workspaceFolder}>, it will be replaced by your workspace's first
+or only folder.
+
 =item pls.perlcritic.enabled - whether to enable linting using L<perlcritic>.
 
 =item pls.perlcritic.perlcriticrc - the location of your C<.perlcriticrc> file.
 
 Defaults to C<~/.perlcriticrc> if not configured.
 
+If you use C<${workspaceFolder}>, it will be replaced by your workspace's first
+or only folder.
+
+If you have the RequireTidyCode policy enabled, it will be configured to use
+the C<.perltidyrc> from pls.perltidy.perltidyrc.
+
 =item pls.syntax.enabled - whether to enable syntax checking.
 
 =item pls.syntax.perl - path to an alternate C<perl> to use for syntax checking.
 
 Defaults to the C<perl> used to run PLS.
 
+If you use C<${workspaceFolder}>, it will be replaced by your workspace's first
+or only folder.
+
+Globbing is also performed against this path.
+
 =item pls.syntax.args - additional arguments to pass when syntax checking.
 
 This is useful if there is a BEGIN block in your code that changes
@@ -101,7 +115,7 @@ or have `perl` in the shebang line that are not `.t` files.
 
 =head1 CAVEATS
 
-pls is known to be compatible with Visual Studio Code, Neovim, and BBEdit.
+pls is known to be compatible with Visual Studio Code, Neovim, BBEdit, and emacs.
 
 pls will perform much better if you have an XS JSON module installed.
 If you install L<Cpanel::JSON::XS> or L<JSON::XS>, it will use one of those
@@ -114,7 +128,7 @@ L<https://marketplace.visualstudio.com/items?itemName=FractalBoy.pls>
 
 =head1 COPYRIGHT
 
-Copyright 2022 Marc Reisner
+Copyright (c) 2024 Marc Reisner
 
 =head1 LICENSE
 
