@@ -30,6 +30,7 @@ use PLS::Parser::Pod::Method;
 use PLS::Parser::Pod::Package;
 use PLS::Parser::Pod::Subroutine;
 use PLS::Parser::Pod::Variable;
+use PLS::Util;
 
 my %FILES;
 my %VERSIONS;
@@ -121,7 +122,7 @@ sub find_current_list
 
     # Find the nearest list structure that completely surrounds the column.
     return first { $_->lsp_column_number < $column_number and $column_number < $_->lsp_column_number + length($_->content) }
-      sort { abs($column_number - $a->lsp_column_number) - abs($column_number - $b->lsp_column_number) }
+      sort { (abs $column_number - $a->lsp_column_number) - (abs $column_number - $b->lsp_column_number) }
       map  { PLS::Parser::Element->new(element => $_, document => $self->{document}, file => $self->{path}) }
       map  { $find->in($_->element) } @elements;
 } ## end sub find_current_list
@@ -203,7 +204,7 @@ sub search_elements_for_definition
 
                     my $external = $self->find_external_package($package);
                     return [$external] if (ref $external eq 'HASH');
-                } ## end else [ if (ref $self->{index}...)]
+                } ## end else[ if (ref $self->{index}...)]
             } ## end if ($match->cursor_on_package...)
 
             if (length $package)
@@ -220,7 +221,7 @@ sub search_elements_for_definition
                         my $found = first { $_->name eq $subroutine } @this_files_subroutines;
                         return {uri => $self->{uri}, range => $found->range} if (blessed($found) and $found->isa('PLS::Parser::Element'));
                     }
-                } ## end else [ if (ref $self->{index}...)]
+                } ## end else[ if (ref $self->{index}...)]
 
                 my $external = $self->find_external_subroutine($package, $subroutine);
                 return [$external] if (ref $external eq 'HASH');
@@ -244,7 +245,7 @@ sub search_elements_for_definition
                 my $results = $self->{index}->find_package_subroutine($class, $method);
 
                 # fall back to treating as a method instead of class method
-                return $results if (ref $results eq 'ARRAY' and scalar @$results);
+                return $results if (ref $results eq 'ARRAY' and scalar @{$results});
             } ## end if (ref $self->{index}...)
             else
             {
@@ -292,7 +293,7 @@ sub search_elements_for_definition
                     my $external = $self->find_external_package($package);
                     return [$external] if (ref $external eq 'HASH');
                 }
-            } ## end else [ if (length $import) ]
+            } ## end else[ if (length $import)]
         } ## end if (my ($package, $import...))
         if (my $variable = $match->variable_name())
         {
@@ -322,7 +323,7 @@ sub search_elements_for_definition
 
             $external = $self->find_external_subroutine($package_name, $subroutine_name);
             return [$external] if (ref $external eq 'HASH');
-        } ## end else [ if (ref $self->{index}...)]
+        } ## end else[ if (ref $self->{index}...)]
 
     } ## end if (my $link = $self->...)
 
@@ -387,7 +388,7 @@ sub pod_link
             $link =~ s/^[^<]*\|//;
             $link =~ s/\/[^>]*$//;
             return $link;
-        } ## end while ($line =~ m{ ) (})
+        } ## end while ($line =~ m{ })
 
         last;
     } ## end while (my $line = <$fh>)
@@ -429,7 +430,7 @@ sub find_pod
                     $args{packages}   = [$package];
                     delete $args{package};
                     $class_name = 'PLS::Parser::Pod::Subroutine';
-                } ## end else [ if ($import =~ /^[\$\@\%]/...)]
+                } ## end else[ if ($import =~ /^[\$\@\%]/...)]
             } ## end if (length $import)
 
             my $pod = $class_name->new(%args);
@@ -678,7 +679,7 @@ sub go_to_variable_definition
                         last OUTER;
                     }
                 } ## end foreach my $child ($condition...)
-            } ## end else [ if ($cursor->type eq 'foreach'...)]
+            } ## end else[ if ($cursor->type eq 'foreach'...)]
         } ## end elsif ($cursor->isa('PPI::Statement::Compound'...))
 
         last if $cursor == $document;
@@ -747,7 +748,7 @@ sub update_file
     {
         if (ref $change->{range} eq 'HASH')
         {
-            my @lines       = _split_lines($$file);
+            my @lines       = _split_lines(${$file});
             my @replacement = _split_lines($change->{text});
 
             my ($starting_text, $ending_text);
@@ -798,12 +799,12 @@ sub update_file
             # with the replacement, including the existing text that is not changing, that we appended above
             my $lines_replacing = $change->{range}{end}{line} - $change->{range}{start}{line} + 1;
             splice @lines, $change->{range}{start}{line}, $lines_replacing, @replacement;
-            $$file = join '', @lines;
+            ${$file} = join '', @lines;
         } ## end if (ref $change->{range...})
         else
         {
             # no range means we're updating the entire document
-            $$file = $change->{text};
+            ${$file} = $change->{text};
         }
     } ## end foreach my $change (@{$args...})
 
@@ -877,7 +878,7 @@ sub get_constants
         );
 
         @matches = $find->in($self->{document});
-    } ## end else [ if (ref $element eq 'PPI::Statement::Include'...)]
+    } ## end else[ if (ref $element eq 'PPI::Statement::Include'...)]
 
     my @constants;
 
@@ -972,7 +973,7 @@ sub get_variables_fast
     state $variable_rx      = qr/((?&PerlVariable))$PPR::GRAMMAR/;
     my @variables;
 
-    while ($$text =~ /$variable_rx/g)
+    while (${$text} =~ /$variable_rx/g)
     {
         my $declaration = $1;
         my ($lvalue) = $declaration =~ /$lvalue_rx/;
@@ -987,7 +988,7 @@ sub get_variables_fast
 
             push @variables, $variable;
         } ## end while ($lvalue =~ /$variable_rx/g...)
-    } ## end while ($$text =~ /$variable_rx/g...)
+    } ## end while (${$text} =~ /$variable_rx/g...)
 
     return \@variables;
 } ## end sub get_variables_fast
@@ -1009,14 +1010,14 @@ sub get_packages_fast
     state $package_rx = qr/((?&PerlPackageDeclaration))$PPR::GRAMMAR/;
     my @packages;
 
-    while ($$text =~ /$package_rx/g)
+    while (${$text} =~ /$package_rx/g)
     {
         my ($package) = $1 =~ /^package\s+(\S+)/;
         $package =~ s/;$//;
         next unless (length $package);
 
         push @packages, $package;
-    } ## end while ($$text =~ /$package_rx/g...)
+    } ## end while (${$text} =~ /$package_rx/g...)
 
     return \@packages;
 } ## end sub get_packages_fast
@@ -1038,12 +1039,12 @@ sub get_subroutines_fast
     state $sub_rx = qr/sub\b(?&PerlOWS)((?&PerlOldQualifiedIdentifier))$PPR::GRAMMAR/;
     my @subroutine_declarations;
 
-    while ($$text =~ /$sub_rx/g)
+    while (${$text} =~ /$sub_rx/g)
     {
         my $sub = $1;
-        $sub =~ s/^\s+|\s+$//;
-        push @subroutine_declarations, $1;
-    } ## end while ($$text =~ /$sub_rx/g...)
+        $sub =~ s/^\s+|\s+$//g;
+        push @subroutine_declarations, $sub;
+    } ## end while (${$text} =~ /$sub_rx/g...)
 
     return \@subroutine_declarations;
 } ## end sub get_subroutines_fast
@@ -1069,7 +1070,7 @@ sub get_constants_fast
     state $one_constant_rx = qr/use\h+constant\h+((?&PerlBareword))(?&PerlOWS)(?&PerlComma)$PPR::GRAMMAR/;
     my @constants;
 
-    while ($$text =~ /$block_rx/g)
+    while (${$text} =~ /$block_rx/g)
     {
         my $block = $1;
 
@@ -1082,16 +1083,16 @@ sub get_constants_fast
 
             push @constants, $constant;
         } ## end while ($block =~ /$bareword_rx/g...)
-    } ## end while ($$text =~ /$block_rx/g...)
+    } ## end while (${$text} =~ /$block_rx/g...)
 
-    while ($$text =~ /$one_constant_rx/g)
+    while (${$text} =~ /$one_constant_rx/g)
     {
         my $constant = $1;
         next unless (length $constant);
         $constant =~ s/^\s+|\s+$//g;
 
         push @constants, $constant;
-    } ## end while ($$text =~ /$one_constant_rx/g...)
+    } ## end while (${$text} =~ /$one_constant_rx/g...)
 
     return \@constants;
 } ## end sub get_constants_fast
@@ -1108,7 +1109,7 @@ sub get_imports
 
     my @imports;
 
-    while ($$text =~ /$use_rx/g)
+    while (${$text} =~ /$use_rx/g)
     {
         my $use = $1;
 
@@ -1121,7 +1122,7 @@ sub get_imports
 
             push @imports, {use => $use, module => $module};
         } ## end if ($use =~ /$identifier_rx/...)
-    } ## end while ($$text =~ /$use_rx/g...)
+    } ## end while (${$text} =~ /$use_rx/g...)
 
     return \@imports;
 } ## end sub get_imports
@@ -1142,7 +1143,7 @@ sub format_range
 
     if (ref $text ne 'SCALAR')
     {
-        return (0, {code => -32700, message => 'Could not get document text.'});
+        return (0, {code => -32_700, message => 'Could not get document text.'});
     }
 
     my $selection  = '';
@@ -1154,7 +1155,7 @@ sub format_range
         # just format up to the line before that
         $range->{end}{line}-- if ($range->{end}{character} == 0);
 
-        my @lines = _split_lines($$text);
+        my @lines = _split_lines(${$text});
         @lines = @lines[$range->{start}{line} .. $range->{end}{line}];
 
         # ignore the column, and just format the entire line.
@@ -1167,7 +1168,7 @@ sub format_range
     else
     {
         $whole_file = 1;
-        $selection  = $$text;
+        $selection  = ${$text};
         my $lines = () = $selection =~ m{($/)}g;
         $lines++;
 
@@ -1181,7 +1182,7 @@ sub format_range
                           character => 0
                          }
                  };
-    } ## end else [ if (ref $range eq 'HASH'...)]
+    } ## end else[ if (ref $range eq 'HASH'...)]
 
     my $formatted = '';
     my $stderr    = '';
@@ -1191,7 +1192,14 @@ sub format_range
         $argv .= $args{formatting_options}{insertSpaces} ? ' -i=' : ' -et=';
         $argv .= $args{formatting_options}{tabSize};
     }
-    my ($perltidyrc) = glob $args{perltidyrc};
+
+    my ($perltidyrc) = PLS::Util::resolve_workspace_relative_path($args{perltidyrc}, $args{workspace_folders});
+
+    if (not length $perltidyrc)
+    {
+        ($perltidyrc) = glob $perltidyrc;
+    }
+
     undef $perltidyrc if (not length $perltidyrc or not -f $perltidyrc or not -r $perltidyrc);
     my $error = Perl::Tidy::perltidy(source => \$selection, destination => \$formatted, stderr => \$stderr, perltidyrc => $perltidyrc, argv => $argv);
 
@@ -1242,7 +1250,7 @@ sub format
 {
     my ($class, %args) = @_;
 
-    return $class->format_range(formatting_options => $args{formatting_options}, text => $args{text}, perltidyrc => $args{perltidyrc});
+    return $class->format_range(formatting_options => $args{formatting_options}, text => $args{text}, perltidyrc => $args{perltidyrc}, workspace_folders => $args{workspace_folders});
 }
 
 =head2 _ppi_location
@@ -1278,7 +1286,7 @@ sub text_from_uri
         open my $fh, '<', $file->file or return;
         my $text = do { local $/; <$fh> };
         return \$text;
-    } ## end else [ if (ref $FILES{$uri} eq...)]
+    } ## end else[ if (ref $FILES{$uri} eq...)]
 } ## end sub text_from_uri
 
 sub uri_version
@@ -1325,7 +1333,7 @@ sub _get_ppi_document
             my $line     = $args{line};
             my $new_line = $/;
 
-            my ($text) = $$file =~ /(?:[^$new_line]*$new_line){$line}([^$new_line]*)$new_line?/m;
+            my ($text) = ${$file} =~ /(?:[^$new_line]*$new_line){$line}([^$new_line]*)$new_line?/m;
 
             if (length $text)
             {
@@ -1820,8 +1828,8 @@ sub sort_imports
 
     foreach my $child ($doc->children)
     {
-        my $seqno;
-        next unless ($seqno = ($child->isa('PPI::Statement::Include') .. (not $child->isa('PPI::Statement::Include') and not $child->isa('PPI::Token::Whitespace'))));
+        my $seqno = ($child->isa('PPI::Statement::Include') .. (not $child->isa('PPI::Statement::Include') and not $child->isa('PPI::Token::Whitespace')));
+        next                                     if (not $seqno);
         last                                     if ($seqno =~ /E0/);
         $insert_after = $child->previous_sibling if ($seqno eq '1');
 
@@ -1857,7 +1865,7 @@ sub sort_imports
             {
                 push @internal_modules, $child;
             }
-        } ## end else [ if ($child->pragma eq ...)]
+        } ## end else[ if ($child->pragma eq ...)]
 
         $child->remove;
     } ## end foreach my $child ($doc->children...)
@@ -1872,14 +1880,15 @@ sub sort_imports
     # There doesn't seem to be a better way to do this other than to use this private method.
     $insert_after->__insert_after(@special_pragmas, @isa_pragmas, @pragmas, @installed_modules, @internal_modules, @constant_pragmas);
 
-    open my $fh, '<', $self->get_full_text();
-
     my $lines;
 
-    while (my $line = <$fh>)
+    if (open my $fh, '<', $self->get_full_text())
     {
-        $lines = $.;
-    }
+        while (my $line = <$fh>)
+        {
+            $lines = $.;
+        }
+    } ## end if (open my $fh, '<', ...)
 
     return \($doc->serialize), $lines;
 } ## end sub sort_imports
