@@ -7,7 +7,7 @@ use parent 'PLS::Parser::Pod::Subroutine';
 
 =head1 NAME
 
-PLS::Parser::Pod::Builtin
+PLS::Parser::Pod::ClassMethod
 
 =head1 DESCRIPTION
 
@@ -16,11 +16,4 @@ class methods.
 
 =cut
 
-sub name
-{
-    my ($self) = @_;
-
-    my $name = $self->{package} . '->' . $self->{subroutine};
-}
-
 1;
