@@ -6,6 +6,7 @@ use warnings;
 use parent 'PLS::Server::Request';
 
 use PLS::Parser::Document;
+use PLS::Parser::PackageSymbols;
 use PLS::Server::Request::TextDocument::PublishDiagnostics;
 
 =head1 NAME
@@ -28,6 +29,11 @@ sub service
 
     $server->send_server_request(PLS::Server::Request::TextDocument::PublishDiagnostics->new(uri => $text_document->{uri}));
 
+    # Warm up the cache for imported package symbols
+    my $text    = PLS::Parser::Document->text_from_uri($text_document->{uri});
+    my $imports = PLS::Parser::Document->get_imports($text);
+    PLS::Parser::PackageSymbols::get_imported_package_symbols($PLS::Server::State::CONFIG, @{$imports})->retain();
+
     return;
 } ## end sub service
 
