@@ -27,9 +27,9 @@ sub new
                       result => undef
                      }, $class;
 
-    my $document = PLS::Parser::Document->new(uri => $request->{params}{textDocument}{uri});
+    my $document = PLS::Parser::Document->new(uri => $request->{params}{textDocument}{uri}, line => $request->{params}{position}{line});
     return $self if (ref $document ne 'PLS::Parser::Document');
-    my ($ok, $pod) = $document->find_pod($request->{params}{textDocument}{uri}, @{$request->{params}{position}}{qw(line character)});
+    my ($ok, $pod) = $document->find_pod($request->{params}{textDocument}{uri}, 1, $request->{params}{position}{character});
     return $self unless $ok;
 
     $self->{result} = {
